# Installation Guide

## Quick Start

### 1. Install Prerequisites

First, install Node.js and npm if you haven't already:

```bash
# On macOS with Homebrew
brew install node

# On Ubuntu/Debian
curl -fsSL https://deb.nodesource.com/setup_lts.x | sudo -E bash -
sudo apt-get install -y nodejs

# On Windows
# Download from https://nodejs.org/
```

### 2. Install openapi2postmanv2

```bash
npm install -g openapi2postmanv2
```

Verify the installation:
```bash
openapi2postmanv2 --version
```

### 3. Install the Python Package

```bash
# Install in development mode
pip install -e .

# Or install dependencies only
pip install -r requirements.txt
```

### 4. Test the Installation

```bash
# Test the CLI tool availability
python -m fastapi_postman_exporter.cli check

# Run the test script
python test_exporter.py
```

## Usage Examples

### Using the CLI

```bash
# Export the example app
python -m fastapi_postman_exporter.cli export --app-path example_app.py --app-name app --output example_collection.json

# With verbose output
python -m fastapi_postman_exporter.cli export --app-path example_app.py --app-name app --output example_collection.json --verbose
```

### Using the Python API

```python
from fastapi import FastAPI
from fastapi_postman_exporter import generate_postman_from_app

app = FastAPI(title="My API")

@app.get("/")
def read_root():
    return {"Hello": "World"}

# Export to Postman collection
generate_postman_from_app(app, "my_collection.json")
```

## Troubleshooting

### Common Issues

1. **"openapi2postmanv2 command not found"**
   - Make sure Node.js and npm are installed
   - Reinstall openapi2postmanv2: `npm install -g openapi2postmanv2`
   - Check your PATH environment variable

2. **"Module not found" errors**
   - Install the package in development mode: `pip install -e .`
   - Check that all dependencies are installed: `pip install -r requirements.txt`

3. **Permission errors**
   - On Unix systems, you might need to use `sudo npm install -g openapi2postmanv2`
   - On Windows, run the command prompt as Administrator

### Verification Steps

1. Check Node.js installation:
   ```bash
   node --version
   npm --version
   ```

2. Check openapi2postmanv2 installation:
   ```bash
   openapi2postmanv2 --version
   ```

3. Check Python package installation:
   ```bash
   python -c "import fastapi_postman_exporter; print('Package installed successfully')"
   ```

4. Run the test script:
   ```bash
   python test_exporter.py
   ``` 